# -*- coding: UTF-8 -*-
# Copyright 2011-2013 Luc Saffre
# License: BSD (see file COPYING for details)


"""
Work in progress.

See :srcref:`docs/tickets/92`.

"""

